#[repr(C)]pub struct MarketMeta {
pub market_token_mint: Pubkey,
pub index_token_mint: Pubkey,
pub long_token_mint: Pubkey,
pub short_token_mint: Pubkey,
}Expand description
Market Metadata.
Fields
market_token_mint: PubkeyMarket token.
index_token_mint: PubkeyIndex token.
long_token_mint: PubkeyLong token.
short_token_mint: PubkeyShort token.
Implementations
Sourceimpl MarketMeta
impl MarketMeta
Sourcepub fn is_collateral_token(&self, token: &Pubkey) -> bool
pub fn is_collateral_token(&self, token: &Pubkey) -> bool
Check if the given token is a valid collateral token.
Sourcepub fn to_token_side(&self, token: &Pubkey) -> Result<bool, MarketError>
pub fn to_token_side(&self, token: &Pubkey) -> Result<bool, MarketError>
Check if the given token is long token or short token, and return it’s side.
Sourcepub fn opposite_token(&self, token: &Pubkey) -> Result<&Pubkey, MarketError>
pub fn opposite_token(&self, token: &Pubkey) -> Result<&Pubkey, MarketError>
Get opposite token.
Sourcepub fn ordered_tokens(&self) -> BTreeSet<Pubkey>
pub fn ordered_tokens(&self) -> BTreeSet<Pubkey>
Get ordered token set.