OrderKind

Enum OrderKind 

#[non_exhaustive]
#[repr(u8)]
pub enum OrderKind { Liquidation = 0, AutoDeleveraging = 1, MarketSwap = 2, MarketIncrease = 3, MarketDecrease = 4, LimitSwap = 5, LimitIncrease = 6, LimitDecrease = 7, StopLossDecrease = 8, }
Order Kind.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Liquidation = 0

Liquidation: allows liquidation of positions if the criteria for liquidation are met.



AutoDeleveraging = 1

Auto-deleveraging Order.



MarketSwap = 2

Swap token A to token B at the current market price.

The order will be cancelled if the min_output_amount cannot be fulfilled.



MarketIncrease = 3

Increase position at the current market price.

The order will be cancelled if the position cannot be increased at the acceptable price.



MarketDecrease = 4

Decrease position at the current market price.

The order will be cancelled if the position cannot be decreased at the acceptable price.



LimitSwap = 5

Limit Swap.



LimitIncrease = 6

Limit Increase.



LimitDecrease = 7

Limit Decrease.



StopLossDecrease = 8

Stop-Loss Decrease.

Implementations

Source

impl OrderKind

pub fn is_market(&self) -> bool

Is market order.

pub fn is_swap(&self) -> bool

Is swap order.

pub fn is_increase_position(&self) -> bool

Is increase position order.

pub fn is_decrease_position(&self) -> bool

Is decrease position order.

pub fn is_market_decrease(&self) -> bool

Is market decrease.