pub struct RoleKey { /* private fields */ }Expand description
The key of a Role.
Implementations
Sourceimpl RoleKey
impl RoleKey
Sourcepub const ORACLE_CONTROLLER: &'static str = "ORACLE_CONTROLLER"
pub const ORACLE_CONTROLLER: &'static str = "ORACLE_CONTROLLER"
Oracle Controller.
Sourcepub const GT_CONTROLLER: &'static str = "GT_CONTROLLER"
pub const GT_CONTROLLER: &'static str = "GT_CONTROLLER"
GT Controller.
Sourcepub const MARKET_KEEPER: &'static str = "MARKET_KEEPER"
pub const MARKET_KEEPER: &'static str = "MARKET_KEEPER"
Market Keeper.
Sourcepub const ORDER_KEEPER: &'static str = "ORDER_KEEPER"
pub const ORDER_KEEPER: &'static str = "ORDER_KEEPER"
Order Keeper.
Sourcepub const FEATURE_KEEPER: &'static str = "FEATURE_KEEPER"
pub const FEATURE_KEEPER: &'static str = "FEATURE_KEEPER"
Feature Keeper.
Sourcepub const CONFIG_KEEPER: &'static str = "CONFIG_KEEPER"
pub const CONFIG_KEEPER: &'static str = "CONFIG_KEEPER"
Config Keeper.
Sourcepub const RESTART_ADMIN: &'static str = "RESTART_ADMIN"
pub const RESTART_ADMIN: &'static str = "RESTART_ADMIN"
Restart Admin. When the cluster restarts, this role can be used for any role, including ADMIN.“
Sourcepub const PRICE_KEEPER: &'static str = "PRICE_KEEPER"
pub const PRICE_KEEPER: &'static str = "PRICE_KEEPER"
Price Keeper.
Sourcepub const MIGRATION_KEEPER: &'static str = "MIGRATION_KEEPER"
pub const MIGRATION_KEEPER: &'static str = "MIGRATION_KEEPER"
Migration Keeper.
Sourcepub const MARKET_CONFIG_KEEPER: &'static str = "MARKET_CONFIG_KEEPER"
pub const MARKET_CONFIG_KEEPER: &'static str = "MARKET_CONFIG_KEEPER"
Addresses with this role can update the restricted list’s market config.