pub struct TokensWithFeed {
pub tokens: Vec<Pubkey>,
pub feeds: Vec<Pubkey>,
pub providers: Vec<u8>,
pub nums: Vec<u16>,
}Expand description
Tokens with feed.
Fields
tokens: Vec<Pubkey>Tokens that require prices,
which must be of the same length with feeds.
feeds: Vec<Pubkey>Token feeds for the tokens,
which must be of the same length with tokens.
providers: Vec<u8>Providers set,
which must be of the same length with nums.
nums: Vec<u16>The numbers of tokens of each provider.
Implementations
Sourceimpl TokensWithFeed
impl TokensWithFeed
Sourcepub fn try_from_records(
records: Vec<TokenRecord>,
) -> Result<Self, TokenConfigError>
pub fn try_from_records( records: Vec<TokenRecord>, ) -> Result<Self, TokenConfigError>