UpdateTokenConfigParams

Struct UpdateTokenConfigParams 

pub struct UpdateTokenConfigParams {
    pub heartbeat_duration: u32,
    pub precision: u8,
    pub feeds: Vec<Pubkey>,
    pub timestamp_adjustments: Vec<u32>,
    pub expected_provider: Option<u8>,
}

Fields

heartbeat_duration: u32

Heartbeat duration.

precision: u8

Price precision.

feeds: Vec<Pubkey>

Feeds.

timestamp_adjustments: Vec<u32>

Timestamp adjustments.

expected_provider: Option<u8>

Expected price provider.

Implementations

Source

impl UpdateTokenConfigParams

pub fn update_price_feed( self, kind: &PriceProviderKind, new_feed: Pubkey, new_timestamp_adjustment: Option<u32>, ) -> Result<Self, TokenConfigError>

Update the feed address for the given price provider. Return error when the feed was not set before.

pub fn with_heartbeat_duration(self, duration: u32) -> Self

Set heartbeat duration.

pub fn with_precision(self, precision: u8) -> Self

Set precision.

pub fn with_expected_provider(self, provider: PriceProviderKind) -> Self

Set expected provider.